@@ -1,6 +1,6 @@
 #!/bin/sh
 # Reading config file
-source /home/user/.ereswap/config
+source /home/user/.config/ereswap/config
 
 # Updating user's defined swaps and it's capabilities in rcS-late
 sed -i "s@mmcblk.p.\([^$]\)@$swap0\1@g" /etc/event.d/rcS-late
